@@ -307,19 +307,19 @@ class xgb_training:
         # precison, recall for the recall_precison curve
         self.precision_curve, self.recall_curve, _ = metrics.precision_recall_curve(self.y_test, self.pred_prob)
         
-        self.model_artefacts[self.model_name]['precision_curve'] = list(self.precision_curve)
+        # self.model_artefacts[self.model_name]['precision_curve'] = list(self.precision_curve)
         self.log.info('Precision values for the precision recall curve created')
         
-        self.model_artefacts[self.model_name]['recall_curve'] = list(self.recall_curve)
+        # self.model_artefacts[self.model_name]['recall_curve'] = list(self.recall_curve)
         self.log.info('Recall values for the precision recall curve created')
         
         # true positive and true negative for te ROC curve
         self.trP, self.trN, _ = metrics.roc_curve(self.y_test, self.pred_prob)
         
-        self.model_artefacts[self.model_name]['trP'] = list(self.trP)
+        # self.model_artefacts[self.model_name]['trP'] = list(self.trP)
         self.log.info('True positive values for the ROC curve created')
 
-        self.model_artefacts[self.model_name]['trN'] = list(self.trN)
+        # self.model_artefacts[self.model_name]['trN'] = list(self.trN)
         self.log.info('True negative values for the ROC curve created')
         
         # precision, recall at different thresholds
@@ -493,9 +493,9 @@ class xgb_training:
             area_roc = self.model_artefacts[self.model_name]['area_roc']
 
 
-            trP = self.model_artefacts[self.model_name]['trP']
+            trP = self.trP
 
-            trN = self.model_artefacts[self.model_name]['trN']
+            trN = self.trN
 
 
             fig = plt.figure(figsize=(15,10), constrained_layout=True)
